==> jasperreports3.7_3.7.6%2Bdfsg.orig.tar.gz: jasperreports3.7-3.7.6.orig/src/net/sf/jasperreports/engine/JRConstants.java <==
/*
 * JasperReports - Free Java Reporting Library.
 * Copyright (C) 2001 - 2009 Jaspersoft Corporation. All rights reserved.
 * http://www.jaspersoft.com
 *
 * Unless you have purchased a commercial license agreement from Jaspersoft,
 * the following license terms apply:
 *
 * This program is part of JasperReports.
 *
 * JasperReports is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * JasperReports is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
 */
package net.sf.jasperreports.engine;


/**
 * @author Teodor Danciu (teodord@users.sourceforge.net)
 * @version $Id: JRConstants.java 3955 2010-09-22 08:19:02Z teodord $
 */
public interface JRConstants
{

	/**
	 * Value used as <code>serialVersionUID</code> for the current version.
	 */
	public static final long SERIAL_VERSION_UID = 10200;
	
	public static final int PSEUDO_SERIAL_VERSION_UID_3_1_0 = 30101;
	
	public static final int PSEUDO_SERIAL_VERSION_UID_3_1_3 = 30103;
	
	public static final int PSEUDO_SERIAL_VERSION_UID_3_5_2 = 30502;
	
	public static final int PSEUDO_SERIAL_VERSION_UID_3_7_2 = 30702;
	
	public static final int PSEUDO_SERIAL_VERSION_UID_3_7_5 = 30705;
	
	public static final int PSEUDO_SERIAL_VERSION_UID = PSEUDO_SERIAL_VERSION_UID_3_7_5;
	
}

==> jasperreports_4.1.3%2Bdfsg.orig.tar.gz: jasperreports-4.1.3.orig/src/net/sf/jasperreports/engine/JRConstants.java <==
/*
 * JasperReports - Free Java Reporting Library.
 * Copyright (C) 2001 - 2011 Jaspersoft Corporation. All rights reserved.
 * http://www.jaspersoft.com
 *
 * Unless you have purchased a commercial license agreement from Jaspersoft,
 * the following license terms apply:
 *
 * This program is part of JasperReports.
 *
 * JasperReports is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * JasperReports is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with JasperReports. If not, see <http://www.gnu.org/licenses/>.
 */
package net.sf.jasperreports.engine;


/**
 * @author Teodor Danciu (teodord@users.sourceforge.net)
 * @version $Id: JRConstants.java 4613 2011-09-16 14:41:12Z teodord $
 */
public interface JRConstants
{

	/**
	 * Value used as <code>serialVersionUID</code> for the current version.
	 */
	public static final long SERIAL_VERSION_UID = 10200;
	
	public static final int PSEUDO_SERIAL_VERSION_UID_3_1_0 = 30101;
	
	public static final int PSEUDO_SERIAL_VERSION_UID_3_1_3 = 30103;
	
	public static final int PSEUDO_SERIAL_VERSION_UID_3_5_2 = 30502;
	
	public static final int PSEUDO_SERIAL_VERSION_UID_3_7_2 = 30702;
	
	public static final int PSEUDO_SERIAL_VERSION_UID_3_7_5 = 30705;
	
	public static final int PSEUDO_SERIAL_VERSION_UID_4_0_2 = 40002;
	
	public static final int PSEUDO_SERIAL_VERSION_UID_4_0_3 = 40003;//4.0.3 is actually 4.1.1
	
	public static final int PSEUDO_SERIAL_VERSION_UID_4_1_3 = 40103;
	
	public static final int PSEUDO_SERIAL_VERSION_UID = PSEUDO_SERIAL_VERSION_UID_4_1_3;
	
}
